@@ -17,6 +17,7 @@ Usage::
 from __future__ import annotations
 
 import sys
+from collections.abc import Mapping, Sequence
 from datetime import datetime
 from typing import Any, Union
 
@@ -30,12 +31,6 @@ from .literals import (
     ValidationModeType,
 )
 
-if sys.version_info >= (3, 9):
-    from builtins import dict as Dict
-    from builtins import list as List
-    from collections.abc import Mapping, Sequence
-else:
-    from typing import Dict, List, Mapping, Sequence
 if sys.version_info >= (3, 12):
     from typing import Literal, NotRequired, TypedDict
 else:
@@ -64,6 +59,7 @@ __all__ = (
     "BatchIsAuthorizedWithTokenInputTypeDef",
     "BatchIsAuthorizedWithTokenOutputItemTypeDef",
     "BatchIsAuthorizedWithTokenOutputTypeDef",
+    "CedarTagValueTypeDef",
     "CognitoGroupConfigurationDetailTypeDef",
     "CognitoGroupConfigurationItemTypeDef",
     "CognitoGroupConfigurationTypeDef",
@@ -208,7 +204,7 @@ class BatchGetPolicyInputItemTypeDef(TypedDict):
 class ResponseMetadataTypeDef(TypedDict):
     RequestId: str
     HTTPStatusCode: int
-    HTTPHeaders: Dict[str, str]
+    HTTPHeaders: dict[str, str]
     RetryAttempts: int
     HostId: NotRequired[str]
 
@@ -269,7 +265,7 @@ class GetIdentitySourceInputTypeDef(TypedDict):
 
 
 class IdentitySourceDetailsTypeDef(TypedDict):
-    clientIds: NotRequired[List[str]]
+    clientIds: NotRequired[list[str]]
     userPoolArn: NotRequired[str]
     discoveryUrl: NotRequired[str]
     openIdIssuer: NotRequired[Literal["COGNITO"]]
@@ -299,7 +295,7 @@ class IdentitySourceFilterTypeDef(TypedDict):
 
 
 class IdentitySourceItemDetailsTypeDef(TypedDict):
-    clientIds: NotRequired[List[str]]
+    clientIds: NotRequired[list[str]]
     userPoolArn: NotRequired[str]
     discoveryUrl: NotRequired[str]
     openIdIssuer: NotRequired[Literal["COGNITO"]]
@@ -344,12 +340,12 @@ class ListTagsForResourceInputTypeDef(TypedDict):
 
 class OpenIdConnectAccessTokenConfigurationDetailTypeDef(TypedDict):
     principalIdClaim: NotRequired[str]
-    audiences: NotRequired[List[str]]
+    audiences: NotRequired[list[str]]
 
 
 class OpenIdConnectAccessTokenConfigurationItemTypeDef(TypedDict):
     principalIdClaim: NotRequired[str]
-    audiences: NotRequired[List[str]]
+    audiences: NotRequired[list[str]]
 
 
 class OpenIdConnectAccessTokenConfigurationTypeDef(TypedDict):
@@ -374,12 +370,12 @@ class OpenIdConnectGroupConfigurationTypeDef(TypedDict):
 
 class OpenIdConnectIdentityTokenConfigurationDetailTypeDef(TypedDict):
     principalIdClaim: NotRequired[str]
-    clientIds: NotRequired[List[str]]
+    clientIds: NotRequired[list[str]]
 
 
 class OpenIdConnectIdentityTokenConfigurationItemTypeDef(TypedDict):
     principalIdClaim: NotRequired[str]
-    clientIds: NotRequired[List[str]]
+    clientIds: NotRequired[list[str]]
 
 
 class OpenIdConnectIdentityTokenConfigurationTypeDef(TypedDict):
@@ -453,8 +449,8 @@ AttributeValueOutputTypeDef = TypedDict(
         "entityIdentifier": NotRequired[EntityIdentifierTypeDef],
         "long": NotRequired[int],
         "string": NotRequired[str],
-        "set": NotRequired[List[Dict[str, Any]]],
-        "record": NotRequired[Dict[str, Dict[str, Any]]],
+        "set": NotRequired[list[dict[str, Any]]],
+        "record": NotRequired[dict[str, dict[str, Any]]],
         "ipaddr": NotRequired[str],
         "decimal": NotRequired[str],
         "datetime": NotRequired[str],
@@ -476,6 +472,21 @@ AttributeValueTypeDef = TypedDict(
         "duration": NotRequired[str],
     },
 )
+CedarTagValueTypeDef = TypedDict(
+    "CedarTagValueTypeDef",
+    {
+        "boolean": NotRequired[bool],
+        "entityIdentifier": NotRequired[EntityIdentifierTypeDef],
+        "long": NotRequired[int],
+        "string": NotRequired[str],
+        "set": NotRequired[Sequence[Mapping[str, Any]]],
+        "record": NotRequired[Mapping[str, Mapping[str, Any]]],
+        "ipaddr": NotRequired[str],
+        "decimal": NotRequired[str],
+        "datetime": NotRequired[str],
+        "duration": NotRequired[str],
+    },
+)
 
 
 class EntityReferenceTypeDef(TypedDict):
@@ -519,7 +530,7 @@ class CreatePolicyOutputTypeDef(TypedDict):
     policyType: PolicyTypeType
     principal: EntityIdentifierTypeDef
     resource: EntityIdentifierTypeDef
-    actions: List[ActionIdentifierTypeDef]
+    actions: list[ActionIdentifierTypeDef]
     createdDate: datetime
     lastUpdatedDate: datetime
     effect: PolicyEffectType
@@ -557,18 +568,18 @@ class GetSchemaOutputTypeDef(TypedDict):
     schema: str
     createdDate: datetime
     lastUpdatedDate: datetime
-    namespaces: List[str]
+    namespaces: list[str]
     ResponseMetadata: ResponseMetadataTypeDef
 
 
 class ListTagsForResourceOutputTypeDef(TypedDict):
-    tags: Dict[str, str]
+    tags: dict[str, str]
     ResponseMetadata: ResponseMetadataTypeDef
 
 
 class PutSchemaOutputTypeDef(TypedDict):
     policyStoreId: str
-    namespaces: List[str]
+    namespaces: list[str]
     createdDate: datetime
     lastUpdatedDate: datetime
     ResponseMetadata: ResponseMetadataTypeDef
@@ -588,7 +599,7 @@ class UpdatePolicyOutputTypeDef(TypedDict):
     policyType: PolicyTypeType
     principal: EntityIdentifierTypeDef
     resource: EntityIdentifierTypeDef
-    actions: List[ActionIdentifierTypeDef]
+    actions: list[ActionIdentifierTypeDef]
     createdDate: datetime
     lastUpdatedDate: datetime
     effect: PolicyEffectType
@@ -613,29 +624,29 @@ class UpdatePolicyTemplateOutputTypeDef(TypedDict):
 
 class IsAuthorizedOutputTypeDef(TypedDict):
     decision: DecisionType
-    determiningPolicies: List[DeterminingPolicyItemTypeDef]
-    errors: List[EvaluationErrorItemTypeDef]
+    determiningPolicies: list[DeterminingPolicyItemTypeDef]
+    errors: list[EvaluationErrorItemTypeDef]
     ResponseMetadata: ResponseMetadataTypeDef
 
 
 class IsAuthorizedWithTokenOutputTypeDef(TypedDict):
     decision: DecisionType
-    determiningPolicies: List[DeterminingPolicyItemTypeDef]
-    errors: List[EvaluationErrorItemTypeDef]
+    determiningPolicies: list[DeterminingPolicyItemTypeDef]
+    errors: list[EvaluationErrorItemTypeDef]
     principal: EntityIdentifierTypeDef
     ResponseMetadata: ResponseMetadataTypeDef
 
 
 class CognitoUserPoolConfigurationDetailTypeDef(TypedDict):
     userPoolArn: str
-    clientIds: List[str]
+    clientIds: list[str]
     issuer: str
     groupConfiguration: NotRequired[CognitoGroupConfigurationDetailTypeDef]
 
 
 class CognitoUserPoolConfigurationItemTypeDef(TypedDict):
     userPoolArn: str
-    clientIds: List[str]
+    clientIds: list[str]
     issuer: str
     groupConfiguration: NotRequired[CognitoGroupConfigurationItemTypeDef]
 
@@ -663,7 +674,7 @@ class GetPolicyStoreOutputTypeDef(TypedDict):
     description: str
     deletionProtection: DeletionProtectionType
     cedarVersion: CedarVersionType
-    tags: Dict[str, str]
+    tags: dict[str, str]
     ResponseMetadata: ResponseMetadataTypeDef
 
 
@@ -697,13 +708,13 @@ class ListPolicyTemplatesInputPaginateTypeDef(TypedDict):
 
 
 class ListPolicyStoresOutputTypeDef(TypedDict):
-    policyStores: List[PolicyStoreItemTypeDef]
+    policyStores: list[PolicyStoreItemTypeDef]
     ResponseMetadata: ResponseMetadataTypeDef
     nextToken: NotRequired[str]
 
 
 class ListPolicyTemplatesOutputTypeDef(TypedDict):
-    policyTemplates: List[PolicyTemplateItemTypeDef]
+    policyTemplates: list[PolicyTemplateItemTypeDef]
     ResponseMetadata: ResponseMetadataTypeDef
     nextToken: NotRequired[str]
 
@@ -744,7 +755,7 @@ class UpdatePolicyDefinitionTypeDef(TypedDict):
 
 
 class ContextDefinitionOutputTypeDef(TypedDict):
-    contextMap: NotRequired[Dict[str, AttributeValueOutputTypeDef]]
+    contextMap: NotRequired[dict[str, AttributeValueOutputTypeDef]]
     cedarJson: NotRequired[str]
 
 
@@ -829,6 +840,7 @@ class EntityItemTypeDef(TypedDict):
     identifier: EntityIdentifierTypeDef
     attributes: NotRequired[Mapping[str, AttributeValueUnionTypeDef]]
     parents: NotRequired[Sequence[EntityIdentifierTypeDef]]
+    tags: NotRequired[Mapping[str, CedarTagValueTypeDef]]
 
 
 ListPoliciesInputPaginateTypeDef = TypedDict(
@@ -865,7 +877,7 @@ class GetPolicyOutputTypeDef(TypedDict):
     policyType: PolicyTypeType
     principal: EntityIdentifierTypeDef
     resource: EntityIdentifierTypeDef
-    actions: List[ActionIdentifierTypeDef]
+    actions: list[ActionIdentifierTypeDef]
     definition: PolicyDefinitionDetailTypeDef
     createdDate: datetime
     lastUpdatedDate: datetime
@@ -882,7 +894,7 @@ class PolicyItemTypeDef(TypedDict):
     lastUpdatedDate: datetime
     principal: NotRequired[EntityIdentifierTypeDef]
     resource: NotRequired[EntityIdentifierTypeDef]
-    actions: NotRequired[List[ActionIdentifierTypeDef]]
+    actions: NotRequired[list[ActionIdentifierTypeDef]]
     effect: NotRequired[PolicyEffectType]
 
 
@@ -915,15 +927,15 @@ class UpdateConfigurationTypeDef(TypedDict):
 class BatchIsAuthorizedOutputItemTypeDef(TypedDict):
     request: BatchIsAuthorizedInputItemOutputTypeDef
     decision: DecisionType
-    determiningPolicies: List[DeterminingPolicyItemTypeDef]
-    errors: List[EvaluationErrorItemTypeDef]
+    determiningPolicies: list[DeterminingPolicyItemTypeDef]
+    errors: list[EvaluationErrorItemTypeDef]
 
 
 class BatchIsAuthorizedWithTokenOutputItemTypeDef(TypedDict):
     request: BatchIsAuthorizedWithTokenInputItemOutputTypeDef
     decision: DecisionType
-    determiningPolicies: List[DeterminingPolicyItemTypeDef]
-    errors: List[EvaluationErrorItemTypeDef]
+    determiningPolicies: list[DeterminingPolicyItemTypeDef]
+    errors: list[EvaluationErrorItemTypeDef]
 
 
 ContextDefinitionUnionTypeDef = Union[ContextDefinitionTypeDef, ContextDefinitionOutputTypeDef]
@@ -935,13 +947,13 @@ class EntitiesDefinitionTypeDef(TypedDict):
 
 
 class BatchGetPolicyOutputTypeDef(TypedDict):
-    results: List[BatchGetPolicyOutputItemTypeDef]
-    errors: List[BatchGetPolicyErrorItemTypeDef]
+    results: list[BatchGetPolicyOutputItemTypeDef]
+    errors: list[BatchGetPolicyErrorItemTypeDef]
     ResponseMetadata: ResponseMetadataTypeDef
 
 
 class ListPoliciesOutputTypeDef(TypedDict):
-    policies: List[PolicyItemTypeDef]
+    policies: list[PolicyItemTypeDef]
     ResponseMetadata: ResponseMetadataTypeDef
     nextToken: NotRequired[str]
 
@@ -982,13 +994,13 @@ class UpdateIdentitySourceInputTypeDef(TypedDict):
 
 
 class BatchIsAuthorizedOutputTypeDef(TypedDict):
-    results: List[BatchIsAuthorizedOutputItemTypeDef]
+    results: list[BatchIsAuthorizedOutputItemTypeDef]
     ResponseMetadata: ResponseMetadataTypeDef
 
 
 class BatchIsAuthorizedWithTokenOutputTypeDef(TypedDict):
     principal: EntityIdentifierTypeDef
-    results: List[BatchIsAuthorizedWithTokenOutputItemTypeDef]
+    results: list[BatchIsAuthorizedWithTokenOutputItemTypeDef]
     ResponseMetadata: ResponseMetadataTypeDef
 
 
@@ -1025,7 +1037,7 @@ class IsAuthorizedWithTokenInputTypeDef(TypedDict):
 
 
 class ListIdentitySourcesOutputTypeDef(TypedDict):
-    identitySources: List[IdentitySourceItemTypeDef]
+    identitySources: list[IdentitySourceItemTypeDef]
     ResponseMetadata: ResponseMetadataTypeDef
     nextToken: NotRequired[str]
 
